'use strict';

var react = require('react');

const getStoreValue = (key, localStorage, initialValue) => {
    if (localStorage && key in localStorage) {
        return localStorage[key];
    }
    try {
        const item = window.localStorage.getItem(key);
        return item ? JSON.parse(item) : initialValue;
    }
    catch (error) {
        console.log(error);
        return initialValue;
    }
};
const useLocalStorage = (key, initialValue, options) => {
    const storedValue = getStoreValue(key, options?.storage, initialValue);
    const setValue = react.useCallback((value) => {
        options?.onChanged?.(key, value);
        window.localStorage.setItem(key, JSON.stringify(value));
    }, [storedValue]);
    return [storedValue, setValue];
};

exports.useLocalStorage = useLocalStorage;
